package com.ruoyi.model.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.model.mapper.AppCleanRequestMapper;
import com.ruoyi.model.domain.AppCleanRequest;
import com.ruoyi.model.service.IAppCleanRequestService;

/**
 * 清洁要求Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-10
 */
@Service
public class AppCleanRequestServiceImpl implements IAppCleanRequestService 
{
    @Autowired
    private AppCleanRequestMapper appCleanRequestMapper;

    /**
     * 查询清洁要求
     * 
     * @param cleanRequestId 清洁要求主键
     * @return 清洁要求
     */
    @Override
    public AppCleanRequest selectAppCleanRequestByCleanRequestId(Long cleanRequestId)
    {
        return appCleanRequestMapper.selectAppCleanRequestByCleanRequestId(cleanRequestId);
    }

    /**
     * 查询清洁要求列表
     * 
     * @param appCleanRequest 清洁要求
     * @return 清洁要求
     */
    @Override
    public List<AppCleanRequest> selectAppCleanRequestList(AppCleanRequest appCleanRequest)
    {
        return appCleanRequestMapper.selectAppCleanRequestList(appCleanRequest);
    }

    /**
     * 新增清洁要求
     * 
     * @param appCleanRequest 清洁要求
     * @return 结果
     */
    @Override
    public int insertAppCleanRequest(AppCleanRequest appCleanRequest)
    {
        return appCleanRequestMapper.insertAppCleanRequest(appCleanRequest);
    }

    /**
     * 修改清洁要求
     * 
     * @param appCleanRequest 清洁要求
     * @return 结果
     */
    @Override
    public int updateAppCleanRequest(AppCleanRequest appCleanRequest)
    {
        return appCleanRequestMapper.updateAppCleanRequest(appCleanRequest);
    }

    /**
     * 批量删除清洁要求
     * 
     * @param cleanRequestIds 需要删除的清洁要求主键
     * @return 结果
     */
    @Override
    public int deleteAppCleanRequestByCleanRequestIds(Long[] cleanRequestIds)
    {
        return appCleanRequestMapper.deleteAppCleanRequestByCleanRequestIds(cleanRequestIds);
    }

    /**
     * 删除清洁要求信息
     * 
     * @param cleanRequestId 清洁要求主键
     * @return 结果
     */
    @Override
    public int deleteAppCleanRequestByCleanRequestId(Long cleanRequestId)
    {
        return appCleanRequestMapper.deleteAppCleanRequestByCleanRequestId(cleanRequestId);
    }

    /**
     * 查询清洁要求列表
     *
     * @return 清洁要求集合
     */
    @Override
    public List<AppCleanRequest> getAppCleanRequestList(){
        return appCleanRequestMapper.getAppCleanRequestList();
    }
}
